==> postgis_3.0.0+dfsg.orig.tar.xz: postgis-3.0.0/README.md <==
Debbie:
   [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_3.0)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_3.0/)
Winnie:
 [![Build Status](https://winnie.postgis.net:444/buildStatus/icon?job=PostGIS_3.0)](https://winnie.postgis.net:444/view/PostGIS/job/PostGIS_3.0/)
Dronie:
 [![Build Status](https://dronie.osgeo.org/api/badges/postgis/postgis/status.svg?branch=svn-3.0)](https://dronie.osgeo.org/postgis/postgis?branch=svn-3.0)
 
Travis:
 [![Build Status](https://api.travis-ci.org/postgis/postgis.svg?branch=svn-3.0,svn-3.0,svn-2.5,svn-2.4,svn-2.3)](http://travis-ci.org/postgis/postgis)
GitLab-CI:
 [![Gitlab-CI](https://gitlab.com/postgis/postgis/badges/svn-3.0/build.svg)](https://gitlab.com/postgis/postgis/commits/svn-3.0)
Drone.io:
 [![Build Status](https://cloud.drone.io/api/badges/postgis/postgis/status.svg?branch=svn-3.0)](https://cloud.drone.io/postgis/postgis?branch=svn-3.0)


Bessie:
 [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_Worker_Run%2Flabel%3Dbessie)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_Worker_Run/label=bessie/) 
Bessie32:
 [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_Worker_Run%2Flabel%3Dbessie32)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_Worker_Run/label=bessie32/) 
Berrie:
 [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_Worker_Run%2Flabel%3Dberrie)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_Worker_Run/label=berrie/)


This file is here to play nicely with modern code repository facilities.
Actual readme is [here](README.postgis).

## Official code repository, issue tracker and wiki:
https://trac.osgeo.org/postgis/

## Official chat room:

Official chat room is the #postgis channel on the
[freenode](https://freenode.net) network.

To participate, point your preferred
[IRC client](https://en.wikipedia.org/wiki/Comparison_of_Internet_Relay_Chat_clients)
to:

 irc://irc.freenode.net/#postgis

Or try a web IRC client like:
 - [qwebirc@freenode](https://webchat.freenode.net/?channels=#postgis)
 - [KiwiIRC](https://kiwiirc.com/client/irc.freenode.net/#postgis)

Or join via [matrix](https://matrix.to/#/#postgis:matrix.org)

## Official source tarball releases

http://postgis.net/source

If you would like to contribute to this project, please refer to our
[contributing guidelines](CONTRIBUTING.md).

## Project Home Page and Manuals
Project homepage: http://postgis.net/
PostGIS Manuals: http://postgis.net/documentation

==> postgis_3.0.2+dfsg.orig.tar.xz: postgis-3.0.2/README.md <==
Debbie:
   [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_3.0)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_3.0/)
Winnie:
 [![Build Status](https://winnie.postgis.net:444/buildStatus/icon?job=PostGIS_3.0)](https://winnie.postgis.net:444/view/PostGIS/job/PostGIS_3.0/)
Dronie:
 [![Build Status](https://dronie.osgeo.org/api/badges/postgis/postgis/status.svg?branch=stable-3.0)](https://dronie.osgeo.org/postgis/postgis?branch=stable-3.0)

Travis:
 [![Build Status](https://api.travis-ci.org/postgis/postgis.svg?branch=stable-3.0)](http://travis-ci.org/postgis/postgis)
GitLab-CI:
 [![Gitlab-CI](https://gitlab.com/postgis/postgis/badges/stable-3.0/pipeline.svg)](https://gitlab.com/postgis/postgis/commits/stable-3.0)
Drone.io:
 [![Build Status](https://cloud.drone.io/api/badges/postgis/postgis/status.svg?branch=stable-3.0)](https://cloud.drone.io/postgis/postgis?branch=stable-3.0)


Bessie:
 [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_Worker_Run%2Flabel%3Dbessie)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_Worker_Run/label=bessie/)
Bessie32:
 [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_Worker_Run%2Flabel%3Dbessie32)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_Worker_Run/label=bessie32/)
Berrie:
 [![Build Status](https://debbie.postgis.net/buildStatus/icon?job=PostGIS_Worker_Run%2Flabel%3Dberrie)](https://debbie.postgis.net/view/PostGIS/job/PostGIS_Worker_Run/label=berrie/)


This file is here to play nicely with modern code repository facilities.
Actual readme is [here](README.postgis).

## Official code repository, issue tracker and wiki:
https://trac.osgeo.org/postgis/

## Official chat room:

Official chat room is the #postgis channel on the
[freenode](https://freenode.net) network.

To participate, point your preferred
[IRC client](https://en.wikipedia.org/wiki/Comparison_of_Internet_Relay_Chat_clients)
to:

 irc://irc.freenode.net/#postgis

Or try a web IRC client like:
 - [qwebirc@freenode](https://webchat.freenode.net/?channels=#postgis)
 - [KiwiIRC](https://kiwiirc.com/client/irc.freenode.net/#postgis)

Or join via [matrix](https://matrix.to/#/#postgis:matrix.org)

## Official source tarball releases

http://postgis.net/source

If you would like to contribute to this project, please refer to our
[contributing guidelines](CONTRIBUTING.md).

## Project Home Page and Manuals
Project homepage: http://postgis.net/
PostGIS Manuals: http://postgis.net/documentation
